@@ -66,8 +66,7 @@ sub _start {
 
   $self->{SESSION_ID} = $_[SESSION]->ID();
   $kernel->refcount_increment( $self->{SESSION_ID}, __PACKAGE__ );
-  $self->{ircd_filter} = POE::Filter::Stackable->new();
-  $self->{ircd_filter}->push( POE::Filter::Line->new(), POE::Filter::IRCD->new() );
+  $self->{ircd_filter} = POE::Filter::Stackable->new( Filters => [ POE::Filter::Line->new(), POE::Filter::IRCD->new() ] );
 
   $self->{listener} = POE::Wheel::SocketFactory->new(
 	BindAddress  => 'localhost',
